@@ -1,3 +1,4 @@
+import asyncio
 import logging
 import sys
 from dataclasses import dataclass, field
@@ -461,7 +462,11 @@ class App:
         # Use the LLM response processor to handle the actual LLM interaction
         # Right before sending to the LLM
         self.logger.info("Thinking...")
-        return self.llm_processor.process(final_messages, self.state.mode, self.state.use_streaming)
+        try:
+            return self.llm_processor.process(final_messages, self.state.mode, self.state.use_streaming)
+        except KeyboardInterrupt:
+            self.logger.info("LLM request interrupted by user (Ctrl+C). Returning to prompt.")
+            return None
 
     def _git_add_commit(self, paths_to_commit: Optional[List[str]] = None):
         """
@@ -680,7 +685,7 @@ class App:
         """Processes the latest user input (already in history), sends to LLM, handles response."""
         response = self._send_to_llm()
 
-        if response:
+        if response is not None:
             self.history_manager.add_message("assistant", response)
             
             # Assuming edit_parser.parse now returns a dict: {"edits": [...], "requested_files": [...]}
@@ -1008,7 +1013,7 @@ class App:
                 # 5. Update the token cache for the *next* prompt render.
                 self._update_and_cache_token_breakdown()
 
-            except KeyboardInterrupt:
+            except (KeyboardInterrupt, asyncio.CancelledError):
                 # User pressed Ctrl+C at the prompt.
                 # This will cancel the current input and prompt again.
                 continue
