@@ -13,7 +13,8 @@ from tinycoder.edit_parser import EditParser
 from tinycoder.file_manager import FileManager
 from tinycoder.git_manager import GitManager
 from tinycoder.input_preprocessor import InputPreprocessor
-from tinycoder.llms import create_llm_client
+
+
 from tinycoder.prompt_builder import PromptBuilder
 from tinycoder.repo_map import RepoMap
 from tinycoder.rule_manager import RuleManager
@@ -33,8 +34,9 @@ from tinycoder.docker_manager import DockerManager
 
 class AppBuilder:
     """Builds the App instance and all its dependencies."""
-    def __init__(self, model: Optional[str], files: List[str], continue_chat: bool, verbose: bool = False):
+    def __init__(self, model: Optional[str], provider: Optional[str], files: List[str], continue_chat: bool, verbose: bool = False):
         self.model_arg = model
+        self.provider_arg = provider
         self.files = files
         self.continue_chat = continue_chat
         self.verbose = verbose
@@ -55,7 +57,6 @@ class AppBuilder:
 
         app = App(
             logger=self.logger,
-            client=self.client,
             model=self.model,
             git_manager=self.git_manager,
             git_root=self.git_root,
@@ -72,6 +73,28 @@ class AppBuilder:
             style=self.style,
         )
 
+        # Initialize provider/base_url from stored preferences if available
+        try:
+            from tinycoder.preferences import load_user_preferences
+            prefs = load_user_preferences()
+            model_info = prefs.get("model")
+            if isinstance(model_info, dict):
+                provider = model_info.get("provider")
+                base_url = model_info.get("base_url")
+                if provider:
+                    app.current_provider = provider
+                    app.llm_processor.provider = provider
+                if base_url:
+                    app.current_base_url = base_url
+                    app.llm_processor.base_url = base_url
+        except Exception:
+            pass
+
+        # If CLI provided a provider, it overrides preferences
+        if getattr(self, "provider_arg", None):
+            app.current_provider = self.provider_arg
+            app.llm_processor.provider = self.provider_arg
+
         app._add_initial_files(self.files)
         self._log_final_status(app)
         return app
@@ -100,15 +123,10 @@ class AppBuilder:
         self.logger.debug("Logging setup complete.")
 
     def _init_llm_client(self) -> None:
-        try:
-            self.client = create_llm_client(self.model_arg)
-            self.model = self.client.model
-            self.logger.debug(f"LLM Client initialized with model: {self.model}")
-        except ValueError as e:
-            self.logger.error(f"Failed to initialize LLM client: {e}", exc_info=True)
-            print(f"{FmtColors['RED']}Error: Failed to initialize LLM client. {e}{RESET}", file=sys.stderr)
-            print("Please check model name or API key environment variables.", file=sys.stderr)
-            sys.exit(1)
+        import os
+        from tinycoder.preferences import load_user_preference_model
+        self.model = self.model_arg or load_user_preference_model() or os.getenv("ZENLLM_DEFAULT_MODEL") or "gpt-4o-mini"
+        self.logger.debug(f"Using zenllm with model: {self.model}")
 
     def _setup_git(self) -> None:
         self.git_manager = GitManager()
