@@ -426,7 +426,7 @@ class CommandHandler:
                     if abs_path and abs_path.exists() and abs_path.is_file():
                         content = self.file_manager.read_file(abs_path)
                         if content is not None:
-                            tokens = int(len(content) / 4)
+                            tokens = self.file_manager.estimate_tokens(content)
                             self.logger.info(f"- {fname_rel} ({tokens} tokens)")
                         else:
                             self.logger.info(f"- {fname_rel} (Error reading file)")
