@@ -116,6 +116,10 @@ class FileManager:
             self.logger.warning(f"Could not perform binary check on {abs_path}, skipping.")
             return True
 
+    def estimate_tokens(self, content: str) -> int:
+        """Estimates the number of tokens based on content length."""
+        return int(len(content) / 4)
+
     def add_file(self, fname: str, force: bool = False) -> bool:
         """
         Adds a file to the chat context. With force=False (default), it excludes
@@ -156,7 +160,12 @@ class FileManager:
             return True
         else:
             self.fnames.add(rel_path)
-            self.logger.info(f"+ {COLORS['CYAN']}{rel_path}{RESET}")
+            content = self.read_file(abs_path)
+            if content is not None:
+                tokens = self.estimate_tokens(content)
+                self.logger.info(f"+ {COLORS['CYAN']}{rel_path}{RESET} ({tokens} tokens)")
+            else:
+                self.logger.info(f"+ {COLORS['CYAN']}{rel_path}{RESET}")
             return True
 
     def drop_file(self, fname: str) -> bool:
